[![Build Status](https://travis-ci.org/stuianna/whaleAlert.svg?branch=master)](https://travis-ci.org/stuianna/whaleAlert)
![Codecov](https://img.shields.io/codecov/c/github/stuianna/whaleAlert)
![GitHub](https://img.shields.io/github/license/stuianna/whaleAlert)

# WhaleAlert - Cryptocurrecy Whale Alert API Logger
